@@ -1,3 +1,6 @@
+import pint
+ureg = pint.get_application_registry()
+
 from scippy.source.SCPIDevice import SCPIDevice as SCPIDevice
 from scippy.source.motor_controller import MotorController
 from scippy.source.Agilent33210A import Agilent33210A as Agilent
